Quick start guide — Django Grappelli 2.4.8 documentation

### Navigation

- index
- next |
- previous |
- Django Grappelli 2.4.8 documentation »

# Quick start guide

For using Grappelli 2.4.8, Django 1.4/1.5 needs to be installed and an Admin Site has to be activated.

## Installation

Using `pip`:

    pip install django-grappelli==2.4.8

Go to https://github.com/sehmaschine/django-grappelli if you need to download a package or clone the repo.

## Setup

Open `settings.py` and add `grappelli` to your `INSTALLED_APPS` (before `django.contrib.admin`):

    INSTALLED_APPS = (
        'grappelli',
        'django.contrib.admin',
    )

Add URL-patterns. The grappelli URLs are needed for related–lookups and autocompletes. Your admin interface is available with the URL you defined for `admin.site`:

    urlpatterns = patterns('',
        (r'^grappelli/', include('grappelli.urls')), # grappelli URLS
        (r'^admin/',  include(admin.site.urls)), # admin site
    )

Make sure `AppDirectoriesFinder` is first with your `STATICFILES_FINDERS`:

    STATICFILES_FINDERS = (
        'django.contrib.staticfiles.finders.AppDirectoriesFinder',
        'django.contrib.staticfiles.finders.FileSystemFinder',
    )

Collect the media files:

    python manage.py collectstatic

## Testing

Start the devserver and login to your admin site:

    python manage.py runserver <IP-address>:8000

Check if everything looks/works as expected. If you’re having problems, see Troubleshooting.

### Navigation

- index
- next |
- previous |
- Django Grappelli 2.4.8 documentation »